@@ -2,8 +2,11 @@
 Implements a client class to query the
 `Deezer API <https://developers.deezer.com/api>`_
 """
+from typing import List, Optional
+
 import requests
 
+from deezer.exceptions import DeezerErrorResponse, DeezerHTTPError
 from deezer.resources import (
     Album,
     Artist,
@@ -61,6 +64,7 @@ class Client:
         "track": Track,
         "user": User,
     }
+    base_url = "https://api.deezer.com"
 
     def __init__(
         self, app_id=None, app_secret=None, access_token=None, headers=None, **kwargs
@@ -122,6 +126,33 @@ class Client:
         request_path = "/".join(request_items)
         return self.url(request_path)
 
+    def request(self, method: str, path: str, **params):
+        """
+        Make a request to the API and parse the response.
+
+        :param method: HTTP verb to use: GET, POST< DELETE, ...
+        :param path: The path to make the API call to (e.g. 'artist/1234')
+        :param params: Query parameters to add the the request
+        :return:
+        """
+        if self.access_token is not None:
+            params["access_token"] = str(self.access_token)
+        response = self.session.request(
+            method,
+            f"{self.base_url}/{path}",
+            params=params,
+        )
+        try:
+            response.raise_for_status()
+        except requests.HTTPError as exc:
+            raise DeezerHTTPError.from_http_error(exc) from exc
+        json_data = response.json()
+        if not isinstance(json_data, dict):
+            return json_data
+        if "error" in json_data:
+            raise DeezerErrorResponse(json_data)
+        return self._process_json(json_data)
+
     def get_object(
         self, object_t, object_id=None, relation=None, parent=None, **params
     ):
@@ -150,6 +181,16 @@ class Client:
         """
         return self.get_object("album", object_id, relation=relation, **kwargs)
 
+    def rate_album(self, album_id: str, note: int) -> bool:
+        """
+        Rate the album of the given ID with the given note.
+
+        The note should be and integer between 1 and 5.
+
+        :returns: boolean whether rating was applied
+        """
+        return self.request("POST", f"album/{album_id}", note=note)
+
     def get_artist(self, object_id, relation=None, **kwargs):
         """
         Get the artist with the provided ID.
@@ -254,6 +295,90 @@ class Client:
         """
         return self.get_object("user", object_id)
 
+    def get_user_albums(self, user_id: Optional[int] = None) -> List[Album]:
+        """
+        Get the favourites albums for the given user_id if provided or current user if not.
+
+        :param user_id: the user ID to get favourites albums.
+        :return: a list of :class:`~deezer.resources.Album` instances.
+        """
+        user_id_str = str(user_id) if user_id else "me"
+        return self.request("GET", f"user/{user_id_str}/albums")
+
+    def add_user_album(self, album_id: int) -> bool:
+        """
+        Add an album to the user's library
+
+        :param album_id: the ID of the album to add.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("POST", "user/me/albums", album_id=album_id)
+
+    def remove_user_album(self, album_id: int) -> bool:
+        """
+        Remove an album from the user's library
+
+        :param album_id: the ID of the album to remove.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("DELETE", "user/me/albums", album_id=album_id)
+
+    def get_user_artists(self, user_id: Optional[int] = None) -> List[Artist]:
+        """
+        Get the favourites artists for the given user_id if provided or current user if not.
+
+        :param user_id: the user ID to get favourites artists.
+        :return: a list of :class:`~deezer.resources.Artist` instances.
+        """
+        user_id_str = str(user_id) if user_id else "me"
+        return self.request("GET", f"user/{user_id_str}/artists")
+
+    def add_user_artist(self, artist_id: int) -> bool:
+        """
+        Add an artist to the user's library
+
+        :param artist_id: the ID of the artist to add.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("POST", "user/me/artists", artist_id=artist_id)
+
+    def remove_user_artist(self, artist_id: int) -> bool:
+        """
+        Remove an artist from the user's library
+
+        :param artist_id: the ID of the artist to remove.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("DELETE", "user/me/artists", artist_id=artist_id)
+
+    def get_user_tracks(self, user_id: Optional[int] = None) -> List[Track]:
+        """
+        Get the favourites tracks for the given user_id if provided or current user if not.
+
+        :param user_id: the user ID to get favourites tracks.
+        :return: a list of :class:`~deezer.resources.Track` instances.
+        """
+        user_id_str = str(user_id) if user_id else "me"
+        return self.request("GET", f"user/{user_id_str}/tracks")
+
+    def add_user_track(self, track_id: int) -> bool:
+        """
+        Add a track to the user's library
+
+        :param track_id: the ID of the track to add.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("POST", "user/me/tracks", track_id=track_id)
+
+    def remove_user_track(self, track_id: int) -> bool:
+        """
+        Remove a track from the user's library
+
+        :param track_id: the ID of the track to remove.
+        :return: boolean whether the operation succeeded.
+        """
+        return self.request("DELETE", "user/me/tracks", track_id=track_id)
+
     def search(self, query, relation=None, index=0, limit=25, **kwargs):
         """
         Search track, album, artist or user
