@@ -2,7 +2,6 @@
 Module to implement the various types of resources that
 can be found in the API.
 """
-import warnings
 
 
 class Resource:
@@ -24,23 +23,7 @@ class Resource:
         name = getattr(self, "name", None)
         title = getattr(self, "title", None)
         id_ = getattr(self, "id", None)
-        repr_ = str(name or title or id_)
-        return f"<{self.__class__.__name__}: {repr_}>"
-
-    def asdict(self):  # pragma: no cover
-        """
-        Convert resource to dictionary
-
-        .. deprecated:: 2.3.0
-
-            This method is deprecated and will be removed in the next major version.
-            Please use :class:`~deezer.resources.Resource.as_dict` instead.
-        """
-        warnings.warn(
-            "The Resource.asdict() method is deprecated, "
-            "please use Resource.as_dict() instead."
-        )
-        return self.as_dict()
+        return f"<{self.__class__.__name__}: {name or title or id_}>"
 
     def as_dict(self):
         """
@@ -119,6 +102,15 @@ class Album(Resource):
         """
         return self.iter_relation("tracks", **kwargs)
 
+    def rate(self, note: int) -> bool:
+        """
+        Rate the album with the given note.
+
+        :param note: rating to give.
+        :return: boolean, whether the album was rated
+        """
+        return self.client.rate_album(album_id=self.id, note=note)
+
 
 class Artist(Resource):
     """
@@ -249,7 +241,7 @@ class User(Resource):
 
         :returns: list of :mod:`Album <deezer.resources.Album>` instances
         """
-        return self.get_relation("albums", **kwargs)
+        return self.client.get_user_albums(self.id)
 
     def iter_albums(self, **kwargs):
         """
